#
# -*- coding: utf-8 -*-
# Copyright 2019 Red Hat
# GNU General Public License v3.0+
# (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
"""
The aeosnp interfaces fact class
It is in this file the configuration is collected from the device
for a given resource, parsed, and the facts tree is populated
based on the configuration.
"""

from __future__ import absolute_import, division, print_function

__metaclass__ = type


import re
from ansible_collections.ansible.netcommon.plugins.module_utils.network.common import (
    utils,
)
from ansible_collections.apresia.aeosnp.plugins.module_utils.network.aeosnp.rm_templates.interfaces import (
    InterfacesTemplate,
)

class InterfacesFacts(object):
    """The aeosnp interfaces fact class"""

    def __init__(self, module, subspec="config", options="options"):
        self._module = module

    def get_interfaces_data(self, connection):
        return connection.get("show running-config all function PORT")

    def populate_facts(self, connection, ansible_facts, data=None):
        """Populate the facts for interfaces
        :param connection: the device connection
        :param ansible_facts: Facts dictionary
        :param data: previously collected conf
        :rtype: dictionary
        :returns: facts
        """
        objs = []

        if not data:
            data = self.get_interfaces_data(connection)

        search_result = re.search(r'interface\sport\s1/0/1[\s\S]*', data)
        match_data = search_result.group()

        # operate on a collection of resource x
        slice_config = ("\n" + match_data).split("\ninterface ")
        slice_config.pop(0)

        # parse native config using the Interfaces template
        for conf in slice_config:
            if conf:
                interfaces_parser = InterfacesTemplate(
                    lines=conf.splitlines(), module=self._module
                )
                obj = interfaces_parser.parse()
                if obj:
                    objs.append(obj)

        facts = {}

        if objs:
            ansible_facts["ansible_network_resources"].pop("interfaces", None)

            params = utils.remove_empties(
                {"config": objs}
            )

            facts["interfaces"] = params.get("config", {})
            ansible_facts["ansible_network_resources"].update(facts)
        
        return ansible_facts
        

