#
# -*- coding: utf-8 -*-
# Copyright 2019 Red Hat
# GNU General Public License v3.0+
# (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
"""
The aeosnp vlans fact class
It is in this file the configuration is collected from the device
for a given resource, parsed, and the facts tree is populated
based on the configuration.
"""

from __future__ import absolute_import, division, print_function

__metaclass__ = type

import re
from ansible_collections.ansible.netcommon.plugins.module_utils.network.common import (
    utils,
)

from ansible_collections.apresia.aeosnp.plugins.module_utils.network.aeosnp.rm_templates.vlans import (
    VlansTemplate,
)


class VlansFacts(object):
    """The aeosnp vlans fact class"""

    def __init__(self, module, subspec="config", options="options"):
        self._module = module

    def get_vlans_data(self, connection):
        return connection.get("show vlan")

    def populate_facts(self, connection, ansible_facts, data=None):
        """Populate the facts for vlans
        :param connection: the device connection
        :param ansible_facts: Facts dictionary
        :param data: previously collected conf
        :rtype: dictionary
        :returns: facts
        """

        objs = []

        if not data:
            data = self.get_vlans_data(connection)

        # operate on a collection of resource x
        config = re.split(r'(?=\n\sVLAN)', data)

        # parse native config using the Vlans template
        for conf in config:
            if conf:
                vlans_parser = VlansTemplate(
                    lines=conf.splitlines(), module=self._module
                )
                obj = vlans_parser.parse()
                if obj:
                    objs.append(obj)
        
        facts = {}

        if objs:
            ansible_facts["ansible_network_resources"].pop("vlans", None)

            params = utils.remove_empties(
                {"config": objs}
            )

            facts["vlans"] = params.get("config", {})
            ansible_facts["ansible_network_resources"].update(facts)
