# -*- coding: utf-8 -*-
# Copyright 2021 Red Hat
# GNU General Public License v3.0+
# (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import absolute_import, division, print_function

__metaclass__ = type

"""
The Logging_global parser templates file. This contains
a list of parser definitions and associated functions that
facilitates both facts gathering and native command generation for
the given network resource.
"""

import re
from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.network_template import (
    NetworkTemplate,
)

class Logging_globalTemplate(NetworkTemplate):
    def __init__(self, lines=None, module=None):
        super(Logging_globalTemplate, self).__init__(
            lines=lines, tmplt=self, module=module
        )

    # fmt: off
    PARSERS = [
        {
            "name": "on",
            "getval": re.compile(
                r"""^logging\son
                $""", re.VERBOSE),
            "result": {
                "on": True,
            },
        },
        {
            "name": "command_logging_enable",
            "getval": re.compile(
                r"""^command\slogging\senable
                $""", re.VERBOSE),
            "result": {
                "command_logging_enable": True,
            },
        },
        {
            "name": "source_interface",
            "getval": re.compile(
                r"""^logging\ssource-interface
                (\s(?P<interfaceid>\S+\s\d+))
                $""", re.VERBOSE),
            "result": {
                "source_interface": "{{ interfaceid }}",
            },
        },
        {
            "name": "discriminator",
            "getval": re.compile(
                r"""^logging\sdiscriminator
                (\s(?P<name>\S+))
                (\sfacility\s(?P<facility_filter_mode>drops|includes)\s(?P<string>\S+))?
                (\sseverity\s(?P<severity_filter_mode>drops|includes)\s(?P<severity_list>\S+))?
                $""", re.VERBOSE),
            "result": {
                "discriminator": {
                    "name": "{{ name }}",
                    "facility": {
                        "filter_mode": "{{ facility_filter_mode }}",
                        "string": "{{ string }}",
                    },
                    "severity": {
                        "filter_mode": "{{ severity_filter_mode }}",
                        "severity_list": "{{ severity_list }}",
                    },
                },
            },
        },
        {
            "name": "buffered",
            "getval": re.compile(
                r"""^logging\sbuffered
                (\sseverity\s(?P<severity>\S+))
                (\sdiscriminator\s(?P<name>\S+))?
                (\swrite-delay\s(?P<writedelay>\d+|infinite))
                $""", re.VERBOSE),
            "result": {
                "buffered": {
                    "severity": "{{ severity }}",
                    "discriminator": "{{ name }}",
                    "write_delay": "{{ writedelay }}",
                },
            },
        },
        {
            "name": "console",
            "getval": re.compile(
                r"""^logging\sconsole
                (\sseverity\s(?P<severity>\S+))
                (\sdiscriminator\s(?P<name>\S+))?
                $""", re.VERBOSE),
            "result": {
                "console": {
                    "severity": "{{ severity }}",
                    "discriminator": "{{ name }}",
                },
            },
        },
        {
            "name": "server",
            "getval": re.compile(
                r"""^logging\sserver
                (\s(?P<address>(\d{1,3}\.){3}\d{1,3}|([0-9a-fA-F]{0,4}:*)*))
                (\sseverity\s(?P<severity>\S+))
                (\sfacility\s(?P<facility>\S+))
                (\sdiscriminator\s(?P<name>\S+))?
                (\sport\s(?P<udp_port>\d+))
                $""", re.VERBOSE),
            "result": {
                "server": {
                    "address": "{{ address }}",
                    "severity": "{{ severity }}",
                    "facility": "{{ facility }}",
                    "discriminator": "{{ name }}",
                    "port": "{{ udp_port }}",
                },
            },
        },
    ]
    # fmt: on
